pub struct BasicCompactionRule {
pub tool_result_limit: usize,
pub assistant_content_limit: usize,
pub keep_recent: usize,
}Expand description
A basic compaction rule that compresses large tool results and assistant messages
Fields
tool_result_limit: usizeassistant_content_limit: usizekeep_recent: usizeTrait Implementations
Sourceimpl CompactionRule for BasicCompactionRule
impl CompactionRule for BasicCompactionRule
Sourcefn should_compact(&self, messages: &[ChatMessage]) -> bool
fn should_compact(&self, messages: &[ChatMessage]) -> bool
Determine if compaction should be performed on the given messages
Sourcefn select_targets(&self, messages: &[ChatMessage]) -> Vec<usize>
fn select_targets(&self, messages: &[ChatMessage]) -> Vec<usize>
Select which message indices should be targeted for compaction
Sourcefn apply_compaction(&self, messages: &mut [ChatMessage], targets: &[usize])
fn apply_compaction(&self, messages: &mut [ChatMessage], targets: &[usize])
Apply the compaction to the selected messages