pub enum HookEvent {
TeammateIdle {
agent_id: AgentId,
name: String,
tasks_completed: usize,
},
TaskCreated {
task: Task,
},
TaskCompleted {
task: Task,
agent_id: AgentId,
},
}Expand description
Events that can trigger hooks.
Variants
TeammateIdle
A teammate has finished its current work and is about to go idle.
Return HookResult::Reject with feedback to keep it working.
TaskCreated
A task is being created in the task store.
Return HookResult::Reject to prevent creation.
TaskCompleted
A task is being marked as completed.
Return HookResult::Reject to prevent completion and send feedback.