pub fn redact_error(value: &str, policy: &RedactionPolicy) -> StringExpand description
Apply redaction rules to an error string based on the given policy’s
error level. Same semantics as redact_string, but gated by
RedactionPolicy::error_level.
pub fn redact_error(value: &str, policy: &RedactionPolicy) -> StringApply redaction rules to an error string based on the given policy’s
error level. Same semantics as redact_string, but gated by
RedactionPolicy::error_level.