Module streaming

Module streaming 

Streaming types.

Structs

StreamAccumulator
Helper to accumulate streamed content into a final response.
ToolUseAccumulator
Accumulator for a single tool use during streaming.

Enums

StreamDelta
Events yielded during streaming LLM responses.
StreamErrorKind
Classification of a StreamDelta::Error event.

Type Aliases

StreamBox
Type alias for a boxed stream of stream deltas.