pub struct ArtifactRetentionSnapshot {
pub protect_unknown_threads: bool,
pub threads: BTreeMap<String, ArtifactThreadRetention>,
}Expand description
Durable liveness and reference snapshot supplied by the host.
Fields
protect_unknown_threads: boolFail closed when the host could not establish durable ownership.
threads: BTreeMap<String, ArtifactThreadRetention>Entries keyed by artifact_thread_key.