pub struct ExecStreamCapture {
pub head: Vec<u8>,
pub tail: Vec<u8>,
pub total_bytes: u64,
pub spool: File,
}Expand description
One process stream captured without retaining its full contents in memory.
Fields
head: Vec<u8>tail: Vec<u8>total_bytes: u64spool: FileImplementations
Sourceimpl ExecStreamCapture
impl ExecStreamCapture
Sourcepub fn complete_bytes(&self) -> Option<Vec<u8>>
pub fn complete_bytes(&self) -> Option<Vec<u8>>
Reconstruct the stream only when the bounded windows contain every byte.