HookRegistry

Struct HookRegistry 

pub struct HookRegistry { /* private fields */ }
A registry of hooks keyed by event type.

Wraps a HashMap<HookEvent, Vec<HookCallbackMatcher>> and provides methods to run hooks for specific events.

Example

use starpod_hooks::{HookRegistry, HookEvent, HookCallbackMatcher, hook_fn, HookOutput};

let mut registry = HookRegistry::new();
registry.register(HookEvent::PostToolUse, vec![
    HookCallbackMatcher::new(vec![
        hook_fn(|_input, _id, _cancel| async move {
            Ok(HookOutput::default())
        }),
    ]).with_matcher("Bash"),
]);

assert!(registry.has_hooks(&HookEvent::PostToolUse));
assert!(!registry.has_hooks(&HookEvent::PreToolUse));

Implementations

Source

impl HookRegistry

pub fn new() -> HookRegistry

pub fn from_map( hooks: HashMap<HookEvent, Vec<HookCallbackMatcher>>, ) -> HookRegistry

Create a registry from an existing HashMap.

pub fn with_circuit_breaker(self, config: CircuitBreakerConfig) -> HookRegistry

Set a custom circuit breaker configuration.

pub fn register(&mut self, event: HookEvent, matchers: Vec<HookCallbackMatcher>)

Register matchers for a hook event.

pub fn has_hooks(&self, event: &HookEvent) -> bool

Check if any hooks are registered for the given event.

pub fn get(&self, event: &HookEvent) -> Option<&Vec<HookCallbackMatcher>>

Get the matchers for a given event.

pub fn into_map(self) -> HashMap<HookEvent, Vec<HookCallbackMatcher>>

Consume the registry and return the inner HashMap.

pub fn merge(&mut self, other: HookRegistry)

Merge another registry’s hooks into this one.

pub async fn run_post_tool_use( &self, tool_name: &str, tool_input: &Value, tool_response: &Value, tool_use_id: &str, session_id: &str, cwd: &str, )

Run all matching hooks for PostToolUse.

Hooks are fire-and-forget: errors are logged but do not propagate.

pub async fn run_pre_tool_use( &self, tool_name: &str, tool_input: &Value, tool_use_id: &str, session_id: &str, cwd: &str, ) -> Option<HookOutput>

Run all matching hooks for PreToolUse.

Returns the merged HookOutput from all matching hooks, or None if no hooks matched.

pub async fn run_event(&self, event: &HookEvent, input: HookInput)

Run hooks for a generic (non-tool) event.

Fires all registered hooks for the event. Errors are logged.