SubagentTool

Struct SubagentTool 

pub struct SubagentTool<P, H = DefaultHooks, M = InMemoryStore, S = InMemoryStore>{ /* private fields */ }
Tool for spawning subagents.

This tool allows an agent to spawn a child agent that runs independently and returns only its final response.

Example

use agent_sdk::subagent::{SubagentTool, SubagentConfig};

let config = SubagentConfig::new("analyzer")
    .with_system_prompt("You analyze code...");

let tool = SubagentTool::new(config, provider.clone(), tools.clone(), || {
    std::sync::Arc::new(agent_sdk::InMemoryEventStore::new())
});

Implementations

Source

impl<P> SubagentTool<P, DefaultHooks, InMemoryStore, InMemoryStore>
where P: LlmProvider + 'static,

pub fn new<EF>( config: SubagentConfig, provider: Arc<P>, tools: Arc<ToolRegistry<()>>, event_store_factory: EF, ) -> Self
where EF: Fn() -> Arc<dyn EventStore> + Send + Sync + 'static,

Create a new subagent tool with default hooks and in-memory message/state stores.

Source

impl<P, H, M, S> SubagentTool<P, H, M, S>
where P: LlmProvider + Clone + 'static, H: AgentHooks + Clone + 'static, M: MessageStore + 'static, S: StateStore + 'static,

pub fn with_hooks<H2: AgentHooks + Clone + 'static>( self, hooks: Arc<H2>, ) -> SubagentTool<P, H2, M, S>

Create with custom hooks.

pub fn with_stores<M2, S2, MF, SF>( self, message_factory: MF, state_factory: SF, ) -> SubagentTool<P, H, M2, S2>
where M2: MessageStore + 'static, S2: StateStore + 'static, MF: Fn() -> M2 + Send + Sync + 'static, SF: Fn() -> S2 + Send + Sync + 'static,

Create with custom store factories.

pub const fn config(&self) -> &SubagentConfig

Get the subagent configuration.