pub struct ToolExecutor { /* private fields */ }Expand description
Executes built-in tools (Read, Write, Edit, Bash, Glob, Grep).
Implementations
Sourceimpl ToolExecutor
impl ToolExecutor
Sourcepub fn new(cwd: PathBuf) -> Self
pub fn new(cwd: PathBuf) -> Self
Create a new executor rooted at the given working directory (no path boundary).
Sourcepub fn with_allowed_dirs(cwd: PathBuf, additional: Vec<PathBuf>) -> Self
pub fn with_allowed_dirs(cwd: PathBuf, additional: Vec<PathBuf>) -> Self
Create a new executor with a path boundary.
File-based tools will only operate within cwd and the additional directories.
Sourcepub fn with_env_blocklist(self, blocklist: Vec<String>) -> Self
pub fn with_env_blocklist(self, blocklist: Vec<String>) -> Self
Set environment variable names to strip from child processes.