pub fn redact_value(value: &Value, policy: &RedactionPolicy) -> ValueExpand description
Apply redaction rules to a JSON value based on the given policy’s input level.
None: returns the value unchanged.Baseline: recursively walks JSON objects and redacts values whose keys match sensitive patterns, or string values that match sensitive value prefixes; remaining string leaves are scanned byRedactionPolicy::detector.Full: returnsjson!("[REDACTED]").